@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import os
 
 extensions = [
@@ -19,8 +16,8 @@ master_doc = 'index'
 project = 'pasteme-cli'
 year = '2022'
 author = 'Sadra Yahyapour'
-copyright = '{0}, {1}'.format(year, author)
-version = release = '1.0.1'
+copyright = f'{year}, {author}'
+version = release = '1.0.3'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -40,7 +37,7 @@ html_split_index = False
 html_sidebars = {
     '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
-html_short_title = '%s-%s' % (project, version)
+html_short_title = f'{project}-{version}'
 
 napoleon_use_ivar = True
 napoleon_use_rtype = False
