@@ -1,5 +1,5 @@
 """
-Entrypoint module, in case you use `python -mpasteme_cli`.
+Entrypoint module, in case you use `python -m pasteme_cli`.
 
 
 Why does this file exist, and why __main__? For more info, read:
@@ -8,7 +8,7 @@ Why does this file exist, and why __main__? For more info, read:
 - https://docs.python.org/2/using/cmdline.html#cmdoption-m
 - https://docs.python.org/3/using/cmdline.html#cmdoption-m
 """
-from pasteme_cli.cli import main
+from .cli import main
 
 if __name__ == "__main__":
     main()
